# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`puppet_operational_dashboards`](#puppet_operational_dashboards): Installs Telegraf, InfluxDB, and Grafana to collect and display Puppet metrics
* [`puppet_operational_dashboards::profile::dashboards`](#puppet_operational_dashboardsprofiledashboards): Installs Grafana and several dashboards to display Puppet metrics.  Included via the base class.
* [`puppet_operational_dashboards::profile::postgres_access`](#puppet_operational_dashboardsprofilepostgres_access): Allows Telegraf to connect and collect metrics from postgres nodes
* [`puppet_operational_dashboards::telegraf::agent`](#puppet_operational_dashboardstelegrafagent): Installs and configures Telegraf to query hosts in a Puppet infrastructure. Included by the base class

### Defined types

* [`puppet_operational_dashboards::telegraf::config`](#puppet_operational_dashboardstelegrafconfig): Defined type to create Telegraf configurations for a given service

### Functions

* [`puppet_operational_dashboards::hosts_with_profile`](#puppet_operational_dashboardshosts_with_profile)
* [`puppet_operational_dashboards::pe_profiles_on_host`](#puppet_operational_dashboardspe_profiles_on_host): function used to determine hosts with a Puppet Enterprise profile

## Classes

### <a name="puppet_operational_dashboards"></a>`puppet_operational_dashboards`

Installs Telegraf, InfluxDB, and Grafana to collect and display Puppet metrics

#### Examples

##### Basic usage

```puppet
include puppet_operational_dashboards

class {'puppet_operational_dashboards':
  manage_influxdb => false,
  influxdb_host   => '<influxdb_fqdn>',
}
```

#### Parameters

The following parameters are available in the `puppet_operational_dashboards` class:

* [`manage_influxdb`](#manage_influxdb)
* [`manage_grafana`](#manage_grafana)
* [`influxdb_host`](#influxdb_host)
* [`influxdb_port`](#influxdb_port)
* [`initial_org`](#initial_org)
* [`initial_bucket`](#initial_bucket)
* [`influxdb_token`](#influxdb_token)
* [`telegraf_token_name`](#telegraf_token_name)
* [`manage_telegraf`](#manage_telegraf)
* [`manage_telegraf_token`](#manage_telegraf_token)
* [`use_ssl`](#use_ssl)
* [`influxdb_token_file`](#influxdb_token_file)

##### <a name="manage_influxdb"></a>`manage_influxdb`

Data type: `Boolean`

Whether to manage installation and configuration of InfluxDB.  Defaults to true

Default value: ``true``

##### <a name="manage_grafana"></a>`manage_grafana`

Data type: `Boolean`

Whether to manage installation and configuration of Grafana.  Defaults to true

Default value: ``true``

##### <a name="influxdb_host"></a>`influxdb_host`

Data type: `String`

FQDN of the InfluxDB host.  Defaults to a the value of influxdb::host, or $facts['fqdn'] if unset

Default value: `lookup(influxdb::host, undef, undef, $facts['networking']['fqdn'])`

##### <a name="influxdb_port"></a>`influxdb_port`

Data type: `Integer`

Port used by the InfluxDB service.  Defaults to the value of influxdb::port, or 8086 if unset

Default value: `lookup(influxdb::port, undef, undef, 8086)`

##### <a name="initial_org"></a>`initial_org`

Data type: `String`

Name of the InfluxDB organization to configure. Defaults to the value of influxdb::initial_org, or 'puppetlabs' if unset

Default value: `lookup(influxdb::initial_org, undef, undef, 'puppetlabs')`

##### <a name="initial_bucket"></a>`initial_bucket`

Data type: `String`

Name of the InfluxDB bucket to configure and query. Defaults to the value of influxdb::initial_bucket, or 'puppet_data' if unset

Default value: `lookup(influxdb::initial_bucket, undef, undef, 'puppet_data')`

##### <a name="influxdb_token"></a>`influxdb_token`

Data type: `Optional[Sensitive[String]]`

InfluxDB admin token in Sensitive format.  Defaults to the value of influxdb::token.
See the puppetlabs/influxdb documentation for more information about this token.

Default value: `lookup(influxdb::token, undef, undef, undef)`

##### <a name="telegraf_token_name"></a>`telegraf_token_name`

Data type: `String`

Name of the token to retrieve from InfluxDB if not given $telegraf_token.

Default value: `'puppet telegraf token'`

##### <a name="manage_telegraf"></a>`manage_telegraf`

Data type: `Boolean`

Whether to manage installation and configuration of Telegraf.  Defaults to true.

Default value: ``true``

##### <a name="manage_telegraf_token"></a>`manage_telegraf_token`

Data type: `Boolean`

Whether to create and manage a Telegraf token with permissions to query buckets in the default organization.  Defaults to true.

Default value: ``true``

##### <a name="use_ssl"></a>`use_ssl`

Data type: `Boolean`

Whether to use SSL when querying InfluxDB.  Defaults to true

Default value: ``true``

##### <a name="influxdb_token_file"></a>`influxdb_token_file`

Data type: `String`

Location on disk of an InfluxDB admin token.
This file is written to by the influxdb class during installation and read by the type and providers,
as well Deferred functions in this module.

Default value: `lookup(influxdb::token_file, undef, undef, $facts['identity']['user'] ? {
      'root'  => '/root/.influxdb_token',
      default => "/home/${facts['identity']['user']}/.influxdb_token"
  })`

### <a name="puppet_operational_dashboardsprofiledashboards"></a>`puppet_operational_dashboards::profile::dashboards`

Installs Grafana and several dashboards to display Puppet metrics.  Included via the base class.

#### Examples

##### Basic usage

```puppet
include puppet_operational_dashboards

class {'puppet_operational_dashboards::profile::dashboards':
  token         => '<my_sensitive_token>',
  influxdb_host => '<influxdb_fqdn>',
  influxdb_port => 8086,
  initial_bucket => '<my_bucket>',
}
```

#### Parameters

The following parameters are available in the `puppet_operational_dashboards::profile::dashboards` class:

* [`token`](#token)
* [`grafana_host`](#grafana_host)
* [`grafana_port`](#grafana_port)
* [`grafana_password`](#grafana_password)
* [`grafana_version`](#grafana_version)
* [`grafana_datasource`](#grafana_datasource)
* [`grafana_install`](#grafana_install)
* [`use_ssl`](#use_ssl)
* [`manage_grafana_repo`](#manage_grafana_repo)
* [`influxdb_host`](#influxdb_host)
* [`influxdb_port`](#influxdb_port)
* [`influxdb_bucket`](#influxdb_bucket)
* [`telegraf_token_name`](#telegraf_token_name)
* [`influxdb_token_file`](#influxdb_token_file)

##### <a name="token"></a>`token`

Data type: `Optional[Sensitive[String]]`

Token in Sensitive format used to query InfluxDB. The token must grant priviledges to query the associated bucket in InfluxDB

Default value: ``undef``

##### <a name="grafana_host"></a>`grafana_host`

Data type: `String`

FQDN of the Grafana host.  Defaults to the FQDN of the agent receiving the catalog.

Default value: `$facts['networking']['fqdn']`

##### <a name="grafana_port"></a>`grafana_port`

Data type: `Integer`

Port used by the Grafana service.  Defaults to 3000

Default value: `3000`

##### <a name="grafana_password"></a>`grafana_password`

Data type: `Sensitive[String]`

Grafana admin password in Sensitive format.  Defaults to 'admin'

Default value: `Sensitive('admin')`

##### <a name="grafana_version"></a>`grafana_version`

Data type: `String`

Version of the Grafana package to install.  Defaults to '8.2.2'

Default value: `'8.2.2'`

##### <a name="grafana_datasource"></a>`grafana_datasource`

Data type: `String`

Name to use for the Grafana datasource.  Defaults to 'influxdb_puppet'

Default value: `'influxdb_puppet'`

##### <a name="grafana_install"></a>`grafana_install`

Data type: `String`

Method to use for installing Grafana.  Defaults to using a repository on EL and Debian/Ubuntu, and package for other platforms

Default value: `$facts['os']['family']`

##### <a name="use_ssl"></a>`use_ssl`

Data type: `Boolean`

Whether to use SSL when querying InfluxDB.  Defaults to true

Default value: ``true``

##### <a name="manage_grafana_repo"></a>`manage_grafana_repo`

Data type: `Boolean`

Whether to manage the Grafana repository definition.  Defaults to true.

Default value: ``true``

##### <a name="influxdb_host"></a>`influxdb_host`

Data type: `String`

FQDN of the InfluxDB host.  Defaults to the value of the base class,
which looks up the value of influxdb::host with a default of $facts['fqdn']

Default value: `$puppet_operational_dashboards::influxdb_host`

##### <a name="influxdb_port"></a>`influxdb_port`

Data type: `Integer`

Port used by the InfluxDB service.  Defaults to the value of the base class,
which looks up the value of influxdb::port with a default of 8086

Default value: `$puppet_operational_dashboards::influxdb_port`

##### <a name="influxdb_bucket"></a>`influxdb_bucket`

Data type: `String`

Name of the InfluxDB bucket to query. Defaults to the value of the base class,
which looks up the value of influxdb::initial_bucket with a default of 'puppet_data'

Default value: `$puppet_operational_dashboards::initial_bucket`

##### <a name="telegraf_token_name"></a>`telegraf_token_name`

Data type: `String`

Name of the token to retrieve from InfluxDB if not given $token

Default value: `$puppet_operational_dashboards::telegraf_token_name`

##### <a name="influxdb_token_file"></a>`influxdb_token_file`

Data type: `String`

Location on disk of an InfluxDB admin token.
This token is used in this class in a Deferred function call to retrieve a Telegraf token if $token is unset

Default value: `$puppet_operational_dashboards::influxdb_token_file`

### <a name="puppet_operational_dashboardsprofilepostgres_access"></a>`puppet_operational_dashboards::profile::postgres_access`

Allows Telegraf to connect and collect metrics from postgres nodes

#### Examples

##### Basic usage

```puppet
include puppet_operational_dashboards::profile::postgres_access
```

#### Parameters

The following parameters are available in the `puppet_operational_dashboards::profile::postgres_access` class:

* [`telegraf_hosts`](#telegraf_hosts)

##### <a name="telegraf_hosts"></a>`telegraf_hosts`

Data type: `Array`

A list of FQDNs running Telegraf to allow access to

Default value: `puppet_operational_dashboards::hosts_with_profile('Puppet_operational_dashboards::Telegraf::Agent')`

### <a name="puppet_operational_dashboardstelegrafagent"></a>`puppet_operational_dashboards::telegraf::agent`

Installs and configures Telegraf to query hosts in a Puppet infrastructure. Included by the base class

#### Examples

##### Basic usage

```puppet
include puppet_operational_dashboards

class {'puppet_operational_dashboards::telegraf::agent':
  token => '<sensitive_telegraf_token>',
}
```

#### Parameters

The following parameters are available in the `puppet_operational_dashboards::telegraf::agent` class:

* [`token`](#token)
* [`influxdb_host`](#influxdb_host)
* [`influxdb_port`](#influxdb_port)
* [`influxdb_org`](#influxdb_org)
* [`influxdb_bucket`](#influxdb_bucket)
* [`use_ssl`](#use_ssl)
* [`manage_ssl`](#manage_ssl)
* [`ssl_cert_file`](#ssl_cert_file)
* [`ssl_key_file`](#ssl_key_file)
* [`ssl_ca_file`](#ssl_ca_file)
* [`version`](#version)
* [`collection_method`](#collection_method)
* [`collection_interval`](#collection_interval)
* [`puppetserver_hosts`](#puppetserver_hosts)
* [`puppetdb_hosts`](#puppetdb_hosts)
* [`postgres_hosts`](#postgres_hosts)
* [`profiles`](#profiles)
* [`local_services`](#local_services)
* [`token_name`](#token_name)
* [`influxdb_token_file`](#influxdb_token_file)

##### <a name="token"></a>`token`

Data type: `Optional[Sensitive[String]]`

Telegraf token in Sensitive format.

Default value: ``undef``

##### <a name="influxdb_host"></a>`influxdb_host`

Data type: `String`

FQDN of the InfluxDB host.  Defaults to $facts['fqdn']

Default value: `$puppet_operational_dashboards::influxdb_host`

##### <a name="influxdb_port"></a>`influxdb_port`

Data type: `Integer`

Port used by the InfluxDB service.  Defaults to 8086.

Default value: `$puppet_operational_dashboards::influxdb_port`

##### <a name="influxdb_org"></a>`influxdb_org`

Data type: `String`

Name of the InfluxDB organization. Defaults to 'puppetlabs'.

Default value: `$puppet_operational_dashboards::initial_org`

##### <a name="influxdb_bucket"></a>`influxdb_bucket`

Data type: `String`

Name of the InfluxDB bucket to query. Defaults to 'puppet_data'.

Default value: `$puppet_operational_dashboards::initial_bucket`

##### <a name="use_ssl"></a>`use_ssl`

Data type: `Boolean`

Whether to use SSL when querying InfluxDB.  Defaults to true

Default value: ``true``

##### <a name="manage_ssl"></a>`manage_ssl`

Data type: `Boolean`

Whether to manage Telegraf ssl configuration.  Defaults to true.

Default value: ``true``

##### <a name="ssl_cert_file"></a>`ssl_cert_file`

Data type: `String`

SSL certificate to be used by the telegraf service.  Defaults to the agent certificate issued by the Puppet CA for the local machine.

Default value: `"/etc/puppetlabs/puppet/ssl/certs/${trusted['certname']}.pem"`

##### <a name="ssl_key_file"></a>`ssl_key_file`

Data type: `String`

Private key used in the CSR for the certificate specified by $ssl_cert_file.
Defaults to the private key of the local machine for generating a CSR for the Puppet CA

Default value: `"/etc/puppetlabs/puppet/ssl/private_keys/${trusted['certname']}.pem"`

##### <a name="ssl_ca_file"></a>`ssl_ca_file`

Data type: `String`

CA certificate issued by the CA which signed the certificate specified by $ssl_cert_file.  Defaults to the Puppet CA.

Default value: `'/etc/puppetlabs/puppet/ssl/certs/ca.pem'`

##### <a name="version"></a>`version`

Data type: `String`

Version of the Telegraf package to install. Defaults to '1.21.2'.

Default value: `'1.21.2'`

##### <a name="collection_method"></a>`collection_method`

Data type: `Enum['all', 'local', 'none']`

Determines how metrics will be collected.
'all' will query all Puppet services across all Puppet infrastructure hosts from the node with this class applied.
'local' will query all Puppet services on the node with this class applied.
TODO
'none' will not query any services from the node with this class applied.

Default value: `'all'`

##### <a name="collection_interval"></a>`collection_interval`

Data type: `String`

How frequently to collect metrics.  Defaults to '10m'.

Default value: `'10m'`

##### <a name="puppetserver_hosts"></a>`puppetserver_hosts`

Data type: `Array`

Array of Puppet server hosts to collect metrics from.  Defaults to all Puppet server hosts in a PE infrastructure.
FOSS users need to supply a list of FQDNs

Default value: `puppet_operational_dashboards::hosts_with_profile('Puppet_enterprise::Profile::Master')`

##### <a name="puppetdb_hosts"></a>`puppetdb_hosts`

Data type: `Array`

Array of PuppetDB hosts to collect metrics from.  Defaults to all PuppetDB hosts in a PE infrastructure.
FOSS users need to supply a list of FQDNs

Default value: `puppet_operational_dashboards::hosts_with_profile('Puppet_enterprise::Profile::Puppetdb')`

##### <a name="postgres_hosts"></a>`postgres_hosts`

Data type: `Array`

Array of Postgres hosts to collect metrics from.  Defaults to all Postgres in a PE infrastructure.
FOSS users need to supply a list of FQDNs.

Default value: `puppet_operational_dashboards::hosts_with_profile('Puppet_enterprise::Profile::Database')`

##### <a name="profiles"></a>`profiles`

Data type: `Array[String]`

Array of PE profiles on the node with this class applied.  Used when collection_method is set to 'local'.
FOSS users can use the $local_services parameter.

Default value: `puppet_operational_dashboards::pe_profiles_on_host()`

##### <a name="local_services"></a>`local_services`

Data type: `Array[String]`

Array of FOSS services to collect from when collection_method is set to 'local'.

Default value: `[]`

##### <a name="token_name"></a>`token_name`

Data type: `String`

Name of the token to retrieve from InfluxDB if not given $token

Default value: `$puppet_operational_dashboards::telegraf_token_name`

##### <a name="influxdb_token_file"></a>`influxdb_token_file`

Data type: `String`

Location on disk of an InfluxDB admin token.
This token is used in this class in a Deferred function call to retrieve a Telegraf token if $token is unset

Default value: `$puppet_operational_dashboards::influxdb_token_file`

## Defined types

### <a name="puppet_operational_dashboardstelegrafconfig"></a>`puppet_operational_dashboards::telegraf::config`

Defined type to create Telegraf configurations for a given service

#### Parameters

The following parameters are available in the `puppet_operational_dashboards::telegraf::config` defined type:

* [`service`](#service)
* [`hosts`](#hosts)
* [`ensure`](#ensure)

##### <a name="service"></a>`service`

Data type: `String`

Name of the service to query.  Is the title of the resource.

Default value: `$title`

##### <a name="hosts"></a>`hosts`

Data type: `Array[String[1]]`

Array of hosts running the service

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether the resource should be present or absent

Default value: `'present'`

## Functions

### <a name="puppet_operational_dashboardshosts_with_profile"></a>`puppet_operational_dashboards::hosts_with_profile`

Type: Puppet Language

The puppet_operational_dashboards::hosts_with_profile function.

#### `puppet_operational_dashboards::hosts_with_profile(String $profile)`

The puppet_operational_dashboards::hosts_with_profile function.

Returns: `Array[String]`

##### `profile`

Data type: `String`



### <a name="puppet_operational_dashboardspe_profiles_on_host"></a>`puppet_operational_dashboards::pe_profiles_on_host`

Type: Puppet Language

Queries PuppetDB for Puppet Enterprise profile on the node including the class.
Used by this module to identify Puppet Enterprise API endpoints on the node.

#### `puppet_operational_dashboards::pe_profiles_on_host()`

Queries PuppetDB for Puppet Enterprise profile on the node including the class.
Used by this module to identify Puppet Enterprise API endpoints on the node.

Returns: `Array[String]` An array of PE profiles representing the Puppet server, PDB, and postgres services

